@@ -15,11 +15,11 @@ from immudb.grpc import schema_pb2, schema_pb2_grpc
 from immudb.rootService import RootService
 
 
-    
 def call(service: schema_pb2_grpc.ImmuServiceStub, rs: RootService, kv: dict):
-    request=schema_pb2.SetRequest(
-        KVs=[schema_pb2.KeyValue(key=key, value=value) for key,value in kv.items()]
-        )
+    request = schema_pb2.SetRequest(
+        KVs=[schema_pb2.KeyValue(key=key, value=value)
+             for key, value in kv.items()]
+    )
     msg = service.Set(request)
     return datatypes.SetResponse(
         id=msg.id,
